/* CPT to Cart (options page)
--------------------------------------------------------------- */
.cpt_to_cart_options_screen_shadow {
  display: none;
  position: fixed;
  z-index: 9;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(255, 255, 255, 0.5);
}
.cpt_to_cart_options_popup_opened + .cpt_to_cart_options_screen_shadow {
  display: block;
}

.form-table .cpt_to_cart_options_wrapper {
  padding: 0;
}

.form-table .cpt_to_cart_options th, .form-table .cpt_to_cart_options td {
  padding: 10px 15px;
  position: relative;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_button_popup {
  padding: 0.25em 1em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup {
  padding: 2em;
  border: 1px solid #aaa;
  background-color: #fff;
  display: none;
  min-width: 640px;
  opacity: 0;
  position: absolute;
  z-index: 10;
  top: 3em;
  right: 0;
  -webkit-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.25);
  -ms-box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.25);
  box-shadow: 0 0 10px 0 rgba(0, 0, 0, 0.25);
  margin: 0.5em;
  -webkit-transition: opacity 0.3s ease;
  -ms-transition: opacity 0.3s ease;
  transition: opacity 0.3s ease;
}
@media (max-width: 767px) {
  .form-table .cpt_to_cart_options .cpt_to_cart_options_popup {
    min-width: 480px;
    padding: 1.5em;
  }
}
@media (max-width: 560px) {
  .form-table .cpt_to_cart_options .cpt_to_cart_options_popup {
    min-width: 320px;
    padding: 0.5em;
  }
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup.cpt_to_cart_options_popup_opened {
  display: block;
  opacity: 1;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_title {
  margin: 0 0 1em;
  font-size: 1.2em;
  font-weight: bold;
  text-decoration: underline;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_subtitle {
  margin: 1em 0 0;
  font-weight: bold;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_description {
  margin: 0 0 0.5em;
  font-style: italic;
  font-size: 12px;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close {
  position: absolute;
  z-index: 1;
  top: 0;
  right: 0;
  width: 2em;
  height: 2em;
  line-height: 2em;
  text-align: center;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:before, .form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:after {
  content: '';
  position: absolute;
  z-index: 1;
  top: 1em;
  left: 0.5em;
  width: 1em;
  height: 0;
  border: 1px solid #aaa;
  -webkit-transition: border-color 0.3s ease;
  -ms-transition: border-color 0.3s ease;
  transition: border-color 0.3s ease;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:before {
  -webkit-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  transform: rotate(45deg);
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:after {
  -webkit-transform: rotate(135deg);
  -ms-transform: rotate(135deg);
  transform: rotate(135deg);
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:hover:before, .form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_close:hover:after {
  border-color: #000;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_field + .cpt_to_cart_options_popup_field {
  margin-top: 0.5em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_field input[type="text"][name$="[price_name]"] {
  width: 100%;
  margin-top: 0.3em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_field.cpt_to_cart_options_popup_field_type_radio label + label {
  margin-left: 1em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_field_type_group {
  margin-bottom: 0.5em;
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-wrap: no-wrap;
  -ms-flex-wrap: no-wrap;
  flex-wrap: no-wrap;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_field_type_group:last-child {
  margin-bottom: 1em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_item {
  display: -webkit-flex;
  display: -ms-flexbox;
  display: flex;
  -webkit-flex-direction: column;
  -ms-flex-direction: column;
  flex-direction: column;
  -webkit-justify-content: flex-start;
  -ms-flex-pack: start;
  justify-content: flex-start;
  -webkit-align-items: flex-start;
  -ms-flex-align: start;
  align-items: flex-start;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_type_text {
  padding-right: 0.5em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_type_text input[type="text"] {
  width: 100%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_type_select {
  padding-right: 0.5em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_type_select select {
  width: 100%;
  line-height: 2;
  min-height: 30px;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_add_listener {
  padding: 0.5em 1em;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_remove_listener {
  line-height: 2;
  padding: 0 0.25em;
  color: #666;
  background-color: #f0f0f0;
  border: 1px solid #aaa;
  -webkit-border-radius: 4px;
  -ms-border-radius: 4px;
  border-radius: 4px;
  -webkit-box-sizing: border-box;
  -ms-box-sizing: border-box;
  box-sizing: border-box;
  width: 30px;
  height: 30px;
  line-height: 30px;
  text-align: center;
  -webkit-transition: color 0.3s ease, background-color 0.3s ease;
  -ms-transition: color 0.3s ease, background-color 0.3s ease;
  transition: color 0.3s ease, background-color 0.3s ease;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_remove_listener:before {
  content: '\e927';
  font-family: "trx_addons_icons";
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_remove_listener:hover {
  color: #000;
  background-color: #ddd;
}
@media (max-width: 782px) {
  .form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_type_select select {
    line-height: 1.75;
  }
  .form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_remove_listener {
    width: 40px;
    height: 40px;
    line-height: 40px;
    text-align: center;
  }
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_event_type {
  -webkit-flex-basis: 14%;
  -ms-flex-basis: 14%;
  flex-basis: 14%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_event_name {
  -webkit-flex-basis: 36%;
  -ms-flex-basis: 36%;
  flex-basis: 36%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_link_type {
  -webkit-flex-basis: 14%;
  -ms-flex-basis: 14%;
  flex-basis: 14%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_area {
  -webkit-flex-basis: 14%;
  -ms-flex-basis: 14%;
  flex-basis: 14%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_place {
  -webkit-flex-basis: 16%;
  -ms-flex-basis: 16%;
  flex-basis: 16%;
}
.form-table .cpt_to_cart_options .cpt_to_cart_options_popup .cpt_to_cart_options_popup_group_field_remove_listener {
  -webkit-flex-basis: 6%;
  -ms-flex-basis: 6%;
  flex-basis: 6%;
}

/*# sourceMappingURL=cpt-to-cart.admin.css.map */
