/* CPT to Cart
--------------------------------------------------------------- */
.cpt_to_cart_button,
.cpt_to_cart_link {
  position: relative;
}
.cpt_to_cart_button .cpt_to_cart_text,
.cpt_to_cart_link .cpt_to_cart_text {
  font-weight: inherit !important;
}
.cpt_to_cart_button:before, .cpt_to_cart_button[class*=" icon-"]:before,
.cpt_to_cart_link:before,
.cpt_to_cart_link[class*=" icon-"]:before {
  font-weight: inherit;
  margin-right: 0.25em;
}
.cpt_to_cart_button.loading:after, .cpt_to_cart_button.added:after,
.cpt_to_cart_link.loading:after,
.cpt_to_cart_link.added:after {
  font-family: "trx_addons_icons";
  font-weight: inherit;
  font-size: 0.75em;
  display: inline-block;
  vertical-align: top;
}
.cpt_to_cart_button.loading:after,
.cpt_to_cart_link.loading:after {
  content: "\e800";
  -webkit-animation: spin 2s linear infinite;
  -ms-animation: spin 2s linear infinite;
  animation: spin 2s linear infinite;
}
.cpt_to_cart_button.added:after,
.cpt_to_cart_link.added:after {
  content: "\e900";
}
.cpt_to_cart_button + .added_to_cart,
.cpt_to_cart_link + .added_to_cart {
  display: inline-block;
  vertical-align: middle;
}

.cpt_to_cart_button.loading:after, .cpt_to_cart_button.added:after {
  position: absolute;
  z-index: 1;
  top: 30%;
  right: 1em;
}
.cpt_to_cart_button + .added_to_cart {
  margin-left: 1em;
  margin-top: 1.1em;
}

.cpt_to_cart_link {
  font-weight: normal;
}
.cpt_to_cart_link.loading:after, .cpt_to_cart_link.added:after {
  position: absolute;
  z-index: 1;
  top: 0;
  right: -1.5em;
}
.cpt_to_cart_link + .added_to_cart {
  margin-left: 2em;
  font-size: 0.75em;
}

/* Links inside the post feature image */
[class*="_page_featured"] > .cpt_to_cart_link, [class*="_page_featured"] > .cpt_to_cart_button,
.post_featured > .cpt_to_cart_link,
.post_featured > .cpt_to_cart_button {
  position: absolute;
  z-index: 10;
  top: 1.5em;
  right: 1.5em;
}
[class*="_page_featured"] * > .cpt_to_cart_link,
.post_featured * > .cpt_to_cart_link {
  color: inherit;
}
[class*="_page_featured"] .cpt_to_cart_link + .added_to_cart,
[class*="_page_featured"] .cpt_to_cart_button + .added_to_cart,
.post_featured .cpt_to_cart_link + .added_to_cart,
.post_featured .cpt_to_cart_button + .added_to_cart {
  position: absolute;
  z-index: 10;
  top: 3.5em;
  right: 2.2em;
}

/* Links inside the post item titles */
[class*="_item_title"] > .cpt_to_cart_link, [class*="_item_title"] > .cpt_to_cart_button,
.post_title > .cpt_to_cart_link,
.post_title > .cpt_to_cart_button,
.entry-title > .cpt_to_cart_link,
.entry-title > .cpt_to_cart_button {
  float: right;
  margin: 0 0 0.5em 0.5em;
  font-size: 0.75em;
}

/*# sourceMappingURL=cpt-to-cart.css.map */
